@@ -1,7 +1,6 @@
 #!/usr/bin/env python
 
 import gi
-gi.require_version("Gtk", "2.0")
  
 from gi.repository import Gtk, GdkPixbuf, Gdk, GObject
 from gi.repository import Gio
@@ -21,11 +20,6 @@ except Exception, detail:
 # TODO: Badly need to fix this - overuse of "The" etc.
 gettext.install("mintdesktop", "/usr/share/linuxmint/locale")
 
-# i18n for menu item
-menuName = _("Desktop Settings")
-menuGenericName = _("Desktop Configuration Tool")
-menuComment = _("Fine-tune desktop settings")
-
 class SidePage:
     def __init__(self, notebook_index, name, icon):
         self.notebook_index = notebook_index
@@ -83,6 +77,13 @@ class MintDesktop:
 
     ''' Create the UI '''
     def __init__(self):
+        # Detect which WM is running
+        marco_mode = False
+        wm_info = commands.getoutput("wmctrl -m")        
+        if "Marco" in wm_info:
+            print "Marco WM detected"
+            marco_mode = True
+
         # load our glade ui file in
         self.builder = Gtk.Builder()
         self.builder.add_from_file('/usr/lib/linuxmint/mintDesktop/mintDesktop.ui')
@@ -90,12 +91,15 @@ class MintDesktop:
                
         self.builder.get_object("main_window").connect("destroy", Gtk.main_quit)
                       
-        side_gnome_desktop_options = SidePage(0, _("Desktop"), "user-desktop")
-        side_gnome_windows = SidePage(1, _("Windows"), "preferences-system-windows")
-        side_gnome_interface = SidePage(2, _("Interface"), "preferences-desktop")
+        side_desktop_options = SidePage(0, _("Desktop"), "user-desktop")
+        side_windows = SidePage(1, _("Windows"), "preferences-system-windows")
+        side_interface = SidePage(2, _("Interface"), "preferences-desktop")
         side_terminal = SidePage(3, _("Terminal"), "terminal")
                 
-        self.sidePages = [side_gnome_desktop_options, side_gnome_windows, side_gnome_interface, side_terminal]
+        if marco_mode:
+            self.sidePages = [side_desktop_options, side_windows, side_interface, side_terminal]
+        else:
+            self.sidePages = [side_desktop_options, side_interface, side_terminal]
                 
         # create the backing store for the side nav-view.                    
         theme = Gtk.IconTheme.get_default()
@@ -117,7 +121,6 @@ class MintDesktop:
         # set up larger components.
         self.builder.get_object("main_window").set_title("Desktop Settings")
         self.builder.get_object("main_window").connect("destroy", Gtk.main_quit)
-        self.builder.get_object("button_cancel").connect("clicked", Gtk.main_quit)        
 
         # i18n
         self.builder.get_object("label_desktop_icons").set_markup("<b>" + _("Desktop icons") + "</b>")
